@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 """Tests for mechanize.Browser."""
 
-import sys, os, random
+import StringIO
 from unittest import TestCase
-import StringIO, re, urllib2
+import re
 
 import mechanize
 from mechanize._response import test_html_response
@@ -57,7 +57,7 @@ def make_mock_handler(response_class=MockResponse):
         def handle(self, fn_name, response, *args, **kwds):
             self.parent.calls.append((self, fn_name, args, kwds))
             if response:
-                if isinstance(response, urllib2.HTTPError):
+                if isinstance(response, mechanize.HTTPError):
                     raise response
                 r = response
                 r.seek(0)
@@ -226,14 +226,16 @@ class BrowserTests(TestCase):
         # still get updated
         class Handler2(mechanize.BaseHandler):
             def https_open(self, request):
-                r = urllib2.HTTPError(
+                r = mechanize.HTTPError(
                     "https://example.com/bad", 503, "Oops",
                     MockHeaders(), StringIO.StringIO())
                 return r
         b.add_handler(Handler2())
-        self.assertRaises(urllib2.HTTPError, b.open, "https://example.com/badreq")
+        self.assertRaises(mechanize.HTTPError, b.open,
+                          "https://example.com/badreq")
         self.assertEqual(b.response().geturl(), "https://example.com/bad")
-        self.assertEqual(b.request.get_full_url(), "https://example.com/badreq")
+        self.assertEqual(b.request.get_full_url(),
+                         "https://example.com/badreq")
         self.assert_(same_response(b.back(), r8))
 
         # .close() should make use of Browser methods and attributes complain
@@ -309,7 +311,7 @@ class BrowserTests(TestCase):
                     hdrs["Content-Type"] = ct
                 b.add_handler(make_mock_handler()([("http_open",
                                             MockResponse(url, "", hdrs))]))
-                r = b.open(url)
+                b.open(url)
                 self.assertEqual(b.viewing_html(), expect)
 
         for allow_xhtml in False, True:
@@ -330,7 +332,7 @@ class BrowserTests(TestCase):
                 url = "http://example.com/foo"+ext
                 b.add_handler(make_mock_handler()(
                     [("http_open", MockResponse(url, "", {}))]))
-                r = b.open(url)
+                b.open(url)
                 self.assertEqual(b.viewing_html(), expect)
 
     def test_empty(self):
@@ -447,7 +449,7 @@ class BrowserTests(TestCase):
         # no form is set yet
         self.assertRaises(AttributeError, getattr, b, "possible_items")
         b.select_form("form1")
-        # now unknown methods are fed through to selected ClientForm.HTMLForm
+        # now unknown methods are fed through to selected mechanize.HTMLForm
         self.assertEqual(
             [i.name for i in b.find_control("cheeses").items],
             ["cheddar", "edam"])
@@ -463,7 +465,6 @@ class BrowserTests(TestCase):
         for factory_class in FACTORY_CLASSES:
             self._test_link_encoding(factory_class())
     def _test_link_encoding(self, factory):
-        import urllib
         import mechanize
         from mechanize._rfc3986 import clean_url
         url = "http://example.com/"
@@ -624,7 +625,6 @@ class BrowserTests(TestCase):
             ])
 
     def test_base_uri(self):
-        import mechanize
         url = "http://example.com/"
 
         for html, urls in [
