@@ -1,11 +1,20 @@
-"""Tests for _ClientCookie."""
+"""Tests for _clientcookie."""
 
-import sys, urllib2, re, os, StringIO, mimetools, time, tempfile, errno, inspect
-from time import localtime
-from unittest import TestCase
+import StringIO
+import errno
+import inspect
+import mimetools
+import os
+import re
+import sys
+import tempfile
+import time
+import unittest
 
+import mechanize
 from mechanize._util import hide_experimental_warnings, \
     reset_experimental_warnings
+from mechanize import Request
 
 
 class FakeResponse:
@@ -17,7 +26,6 @@ class FakeResponse:
         self._headers = mimetools.Message(f)
         self._url = url
     def info(self): return self._headers
-    def url(): return self._url
 
 def interact_2965(cookiejar, url, *set_cookie_hdrs):
     return _interact(cookiejar, url, set_cookie_hdrs, "Set-Cookie2")
@@ -27,7 +35,6 @@ def interact_netscape(cookiejar, url, *set_cookie_hdrs):
 
 def _interact(cookiejar, url, set_cookie_hdrs, hdr_name):
     """Perform a single request / response cycle, returning Cookie: header."""
-    from mechanize import Request
     req = Request(url)
     cookiejar.add_cookie_header(req)
     cookie_hdr = req.get_header("Cookie", "")
@@ -65,7 +72,7 @@ def attribute_names(obj):
     return set([spec[0] for spec in inspect.getmembers(obj)
                 if not spec[0].startswith("__")])
 
-class CookieJarInterfaceTests(TestCase):
+class CookieJarInterfaceTests(unittest.TestCase):
 
     def test_add_cookie_header(self):
         from mechanize import CookieJar
@@ -100,11 +107,6 @@ class CookieJarInterfaceTests(TestCase):
             def is_unverifiable(self):
                 self.log_called()
                 return False
-            @property
-            def port(self):
-                import traceback; traceback.print_stack()
-                self.log_called()
-                pass # currently not used, since urllib2 always sets .port None
         jar = CookieJar()
         interact_netscape(jar, "https://example.com:443",
                           "foo=bar; port=443; secure")
@@ -143,11 +145,6 @@ class CookieJarInterfaceTests(TestCase):
             def is_unverifiable(self):
                 self.log_called()
                 return False
-            @property
-            def port(self):
-                import traceback; traceback.print_stack()
-                self.log_called()
-                pass # currently not used, since urllib2 always sets .port None
         jar = CookieJar()
         response = StubResponse()
         request = StubRequest()
@@ -184,7 +181,7 @@ class CookieJarInterfaceTests(TestCase):
         self.assertEquals(request_is_unverifiable(request), False)
 
 
-class CookieTests(TestCase):
+class CookieTests(unittest.TestCase):
     # XXX
     # Get rid of string comparisons where not actually testing str / repr.
     # .clear() etc.
@@ -476,6 +473,16 @@ class CookieTests(TestCase):
         interact_netscape(c, "http://www.acme.com/blah/rhubarb/", 'eggs="bar"')
         assert c._cookies["www.acme.com"].has_key("/blah/rhubarb")
 
+    def test_default_path_with_query(self):
+        cj = mechanize.CookieJar()
+        uri = "http://example.com/?spam/eggs"
+        value = 'eggs="bar"'
+        interact_netscape(cj, uri, value)
+        # default path does not include query, so is "/", not "/?spam"
+        self.assertIn("/", cj._cookies["example.com"])
+        # cookie is sent back to the same URI
+        self.assertEqual(interact_netscape(cj, uri), value)
+
     def test_escape_path(self):
         from mechanize._clientcookie import escape_path
         cases = [
@@ -501,24 +508,21 @@ class CookieTests(TestCase):
             self.assert_(escape_path(arg) == result)
 
     def test_request_path(self):
-        from urllib2 import Request
         from mechanize._clientcookie import request_path
         # with parameters
-        req = Request("http://www.example.com/rheum/rhaponicum;"
+        req = Request("http://www.example.com/rheum/rhaponticum;"
                       "foo=bar;sing=song?apples=pears&spam=eggs#ni")
-        self.assert_(request_path(req) == "/rheum/rhaponicum;"
-                     "foo=bar;sing=song?apples=pears&spam=eggs#ni")
+        self.assertEquals(request_path(req),
+                          "/rheum/rhaponticum;foo=bar;sing=song")
         # without parameters
-        req = Request("http://www.example.com/rheum/rhaponicum?"
+        req = Request("http://www.example.com/rheum/rhaponticum?"
                       "apples=pears&spam=eggs#ni")
-        self.assert_(request_path(req) == "/rheum/rhaponicum?"
-                     "apples=pears&spam=eggs#ni")
+        self.assertEquals(request_path(req), "/rheum/rhaponticum")
         # missing final slash
         req = Request("http://www.example.com")
         self.assert_(request_path(req) == "/")
 
     def test_request_port(self):
-        from urllib2 import Request
         from mechanize._clientcookie import request_port, DEFAULT_HTTP_PORT
         req = Request("http://www.acme.com:1234/",
                       headers={"Host": "www.acme.com:4321"})
@@ -528,7 +532,6 @@ class CookieTests(TestCase):
         assert request_port(req) == DEFAULT_HTTP_PORT
 
     def test_request_host_lc(self):
-        from mechanize import Request
         from mechanize._clientcookie import request_host_lc
         # this request is illegal (RFC2616, 14.2.3)
         req = Request("http://1.1.1.1/",
@@ -554,7 +557,7 @@ class CookieTests(TestCase):
         assert request_host_lc(req) == "example.com"
 
     def test_effective_request_host(self):
-        from mechanize import Request, effective_request_host
+        from mechanize import effective_request_host
         self.assertEquals(
             effective_request_host(Request("http://www.EXAMPLE.com/spam")),
             "www.EXAMPLE.com")
@@ -742,7 +745,6 @@ class CookieTests(TestCase):
 
     def test_domain_allow(self):
         from mechanize import CookieJar, DefaultCookiePolicy
-        from mechanize import Request
 
         c = CookieJar(policy=DefaultCookiePolicy(
             blocked_domains=["acme.com"],
@@ -776,7 +778,6 @@ class CookieTests(TestCase):
 
     def test_domain_block(self):
         from mechanize import CookieJar, DefaultCookiePolicy
-        from mechanize import Request
 
         #import logging; logging.getLogger("mechanize").setLevel(logging.DEBUG)
 
@@ -1072,10 +1073,10 @@ class CookieTests(TestCase):
                           ["longer", "short"])
 
 
-class CookieJarPersistenceTests(TempfileTestMixin, TestCase):
+class CookieJarPersistenceTests(TempfileTestMixin, unittest.TestCase):
 
     def _interact(self, cj):
-        year_plus_one = localtime(time.time())[0] + 1
+        year_plus_one = time.localtime(time.time())[0] + 1
         interact_2965(cj, "http://www.acme.com/",
                       "foo1=bar; max-age=100; Version=1")
         interact_2965(cj, "http://www.acme.com/",
@@ -1121,7 +1122,7 @@ class CookieJarPersistenceTests(TempfileTestMixin, TestCase):
         except ImportError:
             pass
         else:
-            from mechanize import DefaultCookiePolicy, Cookie
+            from mechanize import DefaultCookiePolicy
             filename = self.mktemp()
             hide_experimental_warnings()
             try:
@@ -1147,7 +1148,7 @@ class CookieJarPersistenceTests(TempfileTestMixin, TestCase):
         except ImportError:
             pass
         else:
-            from mechanize import DefaultCookiePolicy, Cookie
+            from mechanize import DefaultCookiePolicy
             filename = self.mktemp()
             hide_experimental_warnings()
             try:
@@ -1184,7 +1185,6 @@ class CookieJarPersistenceTests(TempfileTestMixin, TestCase):
         except ImportError:
             pass
         else:
-            from mechanize import DefaultCookiePolicy, Request
             filename = self.mktemp()
             hide_experimental_warnings()
             try:
@@ -1194,7 +1194,7 @@ class CookieJarPersistenceTests(TempfileTestMixin, TestCase):
             cj.connect()
             # Session cookies (true .discard) and persistent cookies (false
             # .discard) are stored differently.  Check they both get sent.
-            year_plus_one = localtime(time.time())[0] + 1
+            year_plus_one = time.localtime(time.time())[0] + 1
             expires = "expires=09-Nov-%d 23:12:40 GMT" % (year_plus_one,)
             interact_netscape(cj, "http://www.foo.com/", "fooa=bar")
             interact_netscape(cj, "http://www.foo.com/",
@@ -1277,7 +1277,7 @@ class CookieJarPersistenceTests(TempfileTestMixin, TestCase):
 
 
 
-class LWPCookieTests(TestCase, TempfileTestMixin):
+class LWPCookieTests(unittest.TestCase, TempfileTestMixin):
     # Tests taken from libwww-perl, with a few modifications.
 
     def test_netscape_example_1(self):
@@ -1319,7 +1319,7 @@ class LWPCookieTests(TestCase, TempfileTestMixin):
         # most specific cookie must be sent first.  SHIPPING=FEDEX is the
         # most specific and should thus be first.
 
-        year_plus_one = localtime(time.time())[0] + 1
+        year_plus_one = time.localtime(time.time())[0] + 1
 
         headers = []
 
@@ -1604,8 +1604,6 @@ class LWPCookieTests(TestCase, TempfileTestMixin):
 
         c = LWPCookieJar(policy=pol)
 
-        max_age = "max-age=3600"
-
         # illegal domain (no embedded dots)
         cookie = interact_2965(c, "http://www.acme.com",
                                'foo=bar; domain=".com"; version=1')
@@ -1670,8 +1668,8 @@ class LWPCookieTests(TestCase, TempfileTestMixin):
 ##                           r'foo8=bar; version=1; path="/%66oo"')
         # but this is OK, because '<' is not an allowed HTTP URL path
         # character:
-        cookie = interact_2965(c, "http://www.sol.no/<oo/",
-                               r'foo8=bar; version=1; path="/%3coo"')
+        interact_2965(c, "http://www.sol.no/<oo/",
+                      r'foo8=bar; version=1; path="/%3coo"')
         assert len(c) == 6
 
         # save and restore
@@ -1821,7 +1819,7 @@ class LWPCookieTests(TestCase, TempfileTestMixin):
 ##         # X-Meta-Description: Trip.com privacy policy
 ##         # X-Meta-Keywords: privacy policy
 
-##         req = urllib2.Request(
+##         req = mechanize.Request(
 ##             'http://www.trip.com/trs/trip/flighttracker/flight_tracker_home.xsl')
 ##         headers = []
 ##         headers.append("Set-Cookie: trip.appServer=1111-0000-x-024;Domain=.trip.com;Path=/")
@@ -1846,7 +1844,7 @@ class LWPCookieTests(TestCase, TempfileTestMixin):
     def test_session_cookies(self):
         from mechanize import CookieJar, Request
 
-        year_plus_one = localtime(time.time())[0] + 1
+        year_plus_one = time.localtime(time.time())[0] + 1
 
         # Check session cookies are deleted properly by
         # CookieJar.clear_session_cookies method
